; WALK5X.ASM 
;
; Build this simple circuit using the 16C5X PIC of your choice and
; four LEDs (or up to 8 LEDs if you change the constant MSB in
; the program below).  The four resistors R can have values in the
; range 470 ohms to 2.2k depending on how brightly the LEDs
; must be lit.
;
;               /
;            +-O O---+-----------------+----------------------+
;            |       |                 |                      |
;            |       |          +------O------+               |
;            | +     |          |     VDD     | PIC16C5X      |
;         -------    |   ____   |             |        ____   |
;           ---      +--[____]--O MCLR   OSC1 O----+--[____]--+
;         -------         1K    |             |    |   4.7k   |
;  4.5V     ---          ____   |             |    |          |
; battery -------    +--[____]--O RB0-3       |   _|_        _|_
;           ---     _|_  R X 4  |     GND     |   ___ 22pF   ___ 0.1uF
;            | -    \ /^        +------O------+    |          |
;            |      --- LED X 4        |           |          |
;            |       |                 |           |          |
;            +-------+-----------------+-----------+----------+
;
;
;
; The following program illuminates the LEDs one at time in a to-and-fro
; pattern.  So that the same hex file can be used with any 16C5X
; PIC the program relies on the device being blank initially.  This
; means the word at the reset address is known to be 0FFFH (equivalent
; to XORLW 0FFH) and thus the PC simply rolls over to 0 (the start
; address of this program) affecting nothing more than W.  The program
; will still run as intended with virtually any oscillator configuration
; because timing depends on the watchdog rather than the PIC clock.  If
; a non-RC oscillator is used it will be necessary to change the __CONFIG
; line or select the correct oscillator type during programming.
;
; David Tait (david.tait@man.ac.uk)
;
	PROCESSOR       16C54  ;COULD BE ANY 16C5X
	__CONFIG        0FH    ;RC OSC, WATCHDOG
;    
PORTB   EQU     6 
STATUS  EQU     3
CARRY   EQU     0
NOT_TO  EQU     4
RFLG    EQU     8               ;GO RIGHT FLAG
MSB     EQU     3               ;BIT POSITION OF LEFTMOST LED
;
	BTFSS   STATUS,NOT_TO   ;RESET OR WATCHDOG TIMEOUT?
	GOTO    NOINIT          ;SKIP INIT IF TIMEOUT
	MOVLW   1               ;INIT IF RESET
	MOVWF   PORTB
	CLRF    RFLG
NOINIT  CLRW
	TRIS    PORTB           ;PORTB ALL OUTPUTS
	MOVLW   0AH
	OPTION                  ;WATCHDOG PRESCALE 4:1
	BCF     STATUS,CARRY
	BTFSC   RFLG,0          ;CHECK LEFT OR RIGHT
	GOTO    RIGHT
LEFT    RLF     PORTB,F         ;LIGHT LED TO LEFT
	BTFSC   PORTB,MSB       ;LEFTMOST?
	COMF    RFLG,F          ;YES - GO RIGHT NEXT TIME
	SLEEP                 
RIGHT   RRF     PORTB,F         ;LIGHT LED TO RIGHT
	BTFSC   PORTB,0         ;RIGHTMOST?
	COMF    RFLG,F          ;YES - GO LEFT NEXT TIME
	SLEEP
;
	END

