/* upphw.h
 *
 * Defines parallel port connections and low-level I/O macros for
 * PIC16C5X/XX programmer (V-0.1 hardware) described in UPP.PCX.
 *
 *
 * Revision history:
 *
 * 16-Mar-1996: V-0.0; wrote definitions
 * 14-Jul-1996: V-0.1; created separate header file
 * 19-Nov-1996: V-0.2; first public release
 *
 * Copyright (C) 1996 David Tait.  All rights reserved.
 * Permission is granted to use, modify, or redistribute this software
 * so long as it is not sold or exploited for profit.
 *
 * THIS SOFTWARE IS PROVIDED AS IS AND WITHOUT WARRANTY OF ANY KIND,
 * EITHER EXPRESSED OR IMPLIED.
 *
 */

#ifndef __UPPHW_H
#define __UPPHW_H
#include <dos.h>

#ifdef _MSC_VER              	/* changes for Microsoft C V7.00 */
#define outportb(p,v)  	_outp(p,v)
#define inportb(p)   	_inp(p)
#endif

#define BIT(n)  (1<<(n))

	/* connections to LPT data bits */

#define SDA     BIT(0)          /* serial data aka /PROG/VER for 5X */
#define SCL     BIT(1)          /* serial clock aka INCPC for 5X */
#define RLI     BIT(2)          /* input to LSBs (D0-D3) register */
#define RHI     BIT(3)          /* input to MSBs (D4-D11) register */
#define RCL     BIT(4)          /* common register clock (+ve edge) */
#define RLD     BIT(5)          /* common register load */
#define DEN     BIT(6)          /* SDA buffer enable (active low) */
#define CEN     BIT(7)          /* SCL buffer enable; VDD on (active low) */

	/* connections to LPT status bits */

#define S_SDA   BIT(7)          /* SDA input (via SCL buffer) */
#define S_SCL   BIT(6)          /* SCL feedback (via SCL buffer) */
#define S_RLO   BIT(5)          /* output from LSBs register */
#define S_RHO   BIT(4)          /* output from MSBs register */
#define S_28P   BIT(3)          /* 28 (not 18) pin check (via SDA buffer) */

	/* connections to LPT control bits */

#define VPP     BIT(3)          /* pull /MCLR to VPP */
#define RST     BIT(2)          /* pull /MCLR to GND (active low) */


	/* low-level I/O macros */

#define OUTD()		(outportb(d_reg,d_bits))
#define OUTC()		(outportb(c_reg,c_bits^0xB))  /* 3,1,0 inverted */
#define INS()		(inportb(s_reg)^0x80)         /* bit 7 inverted */

#define SDA_HI()        ((d_bits |= SDA), OUTD())
#define SDA_LO()        ((d_bits &= ~SDA), OUTD())
#define SCL_HI()        ((d_bits |= SCL), OUTD())
#define SCL_LO()        ((d_bits &= ~SCL), OUTD())
#define RLI_HI()        (d_bits |= RLI)          /* NOTE: no OUTD() here */
#define RLI_LO()        (d_bits &= ~RLI)
#define RHI_HI()        (d_bits |= RHI)
#define RHI_LO()        (d_bits &= ~RHI)
#define RCL_HI()        ((d_bits |= RCL), OUTD())
#define RCL_LO()        ((d_bits &= ~RCL), OUTD())
#define DISABLE()       ((d_bits |= RLD), OUTD()) /* tristate regs */
#define ENABLE()        ((d_bits &= ~RLD), OUTD())
#define INPUT()         ((d_bits |= DEN), OUTD()) /* tristate SDA buffer */
#define OUTPUT()        ((d_bits &= ~DEN), OUTD())
#define OFF()           ((d_bits |= CEN), OUTD()) /* tristate SCL buffer */
#define ON()            ((d_bits &= ~CEN), OUTD())
#define IDLE()		((d_bits = 0xFF), OUTD())

#define PROGRAM()       ((c_bits = VPP|RST), OUTC())  /* pull MCLR to VPP */
#define RESET()         ((c_bits = 0), OUTC())        /* pull MCLR to GND */
#define FLOAT()         ((c_bits = RST), OUTC())      /* MCLR not driven */

#endif  /*  __UPPHW_H  */
